==> hypre_2.23.0.orig.tar.gz: hypre-2.23.0/src/test/TEST_bench/benchmark_ij.sh <==
#!/bin/sh
# Copyright 1998-2019 Lawrence Livermore National Security, LLC and other
# HYPRE Project Developers. See the top-level COPYRIGHT file for details.
#
# SPDX-License-Identifier: (Apache-2.0 OR MIT)

TNAME=`basename $0 .sh`
RTOL=$1
ATOL=$2

#=============================================================================
# compare with baseline case
#=============================================================================

FILES="\
 ${TNAME}.out.1\
 ${TNAME}.out.2\
 ${TNAME}.out.3\
 ${TNAME}.out.4\
 ${TNAME}.out.5\
 ${TNAME}.out.6\
 ${TNAME}.out.7\
 ${TNAME}.out.8\
 ${TNAME}.out.9\
 ${TNAME}.out.10\
 ${TNAME}.out.11\
 ${TNAME}.out.12\
 ${TNAME}.out.13\
 ${TNAME}.out.14\
 ${TNAME}.out.15\
 ${TNAME}.out.16\
 ${TNAME}.out.17\
 ${TNAME}.out.18\
 ${TNAME}.out.19\
 ${TNAME}.out.20\
 ${TNAME}.out.21\
 ${TNAME}.out.22\
 ${TNAME}.out.23\
 ${TNAME}.out.24\
 ${TNAME}.out.25\
 ${TNAME}.out.26\
 ${TNAME}.out.27\
"

for i in $FILES
do
  echo "# Output file: $i"
  grep -A 3 "Complexity" $i
  tail -3 $i
done > ${TNAME}.out

for i in $FILES
do
  echo "# Output file: $i"
  setup_time=$(grep -A 1 "PCG Setup" $i | tail -n 1)
  echo "PCG Setup"${setup_time}
  solve_time=$(grep -A 1 "PCG Solve" $i | tail -n 1)
  echo "PCG Solve"${solve_time}
done > ${TNAME}.perf.out

# Make sure that the output file is reasonable
RUNCOUNT=`echo $FILES | wc -w`
OUTCOUNT=`grep "Complexity" ${TNAME}.out | wc -l`
if [ "$OUTCOUNT" != "$RUNCOUNT" ]; then
   echo "Incorrect number of runs in ${TNAME}.out" >&2
fi

# Check performance
HOST=`hostname`
case $HOST in
   lassen*)
      SavePerfExt="saved.lassen"
      rtol=0.15
      ;;
   *) SavePerfExt=""
      ;;
esac

if [ -n "$SavePerfExt" ]; then
   ../runcheck.sh $TNAME.perf.out $TNAME.perf.$SavePerfExt $rtol >&2
fi

#=============================================================================
# remove temporary files
#=============================================================================

rm -f ${TNAME}.testdata*

==> hypre-2.24.0.tar.gz: hypre-2.24.0/src/test/TEST_bench/benchmark_ij.sh <==
#!/bin/sh
# Copyright 1998-2019 Lawrence Livermore National Security, LLC and other
# HYPRE Project Developers. See the top-level COPYRIGHT file for details.
#
# SPDX-License-Identifier: (Apache-2.0 OR MIT)

TNAME=`basename $0 .sh`
RTOL=$1
ATOL=$2

#=============================================================================
# compare with baseline case
#=============================================================================

FILES="\
 ${TNAME}.out.1\
 ${TNAME}.out.2\
 ${TNAME}.out.3\
 ${TNAME}.out.4\
 ${TNAME}.out.5\
 ${TNAME}.out.6\
 ${TNAME}.out.7\
 ${TNAME}.out.8\
 ${TNAME}.out.9\
 ${TNAME}.out.10\
 ${TNAME}.out.11\
 ${TNAME}.out.12\
 ${TNAME}.out.13\
 ${TNAME}.out.14\
 ${TNAME}.out.15\
 ${TNAME}.out.16\
 ${TNAME}.out.17\
 ${TNAME}.out.18\
 ${TNAME}.out.19\
 ${TNAME}.out.20\
 ${TNAME}.out.21\
 ${TNAME}.out.22\
 ${TNAME}.out.23\
 ${TNAME}.out.24\
 ${TNAME}.out.25\
 ${TNAME}.out.26\
 ${TNAME}.out.27\
"

for i in $FILES
do
  echo "# Output file: $i"
  grep -A 3 "Complexity" $i
  tail -3 $i
done > ${TNAME}.out

for i in $FILES
do
  echo "# Output file: $i"
  setup_time=$(grep -A 1 "PCG Setup" $i | tail -n 1)
  echo "PCG Setup"${setup_time}
  solve_time=$(grep -A 1 "PCG Solve" $i | tail -n 1)
  echo "PCG Solve"${solve_time}
done > ${TNAME}.perf.out

# Make sure that the output file is reasonable
RUNCOUNT=`echo $FILES | wc -w`
OUTCOUNT=`grep "Iterations" ${TNAME}.out | wc -l`
if [ "$OUTCOUNT" != "$RUNCOUNT" ]; then
   echo "Incorrect number of runs in ${TNAME}.out" >&2
fi

# Check performance
HOST=`hostname`
case $HOST in
   lassen*)
      SavePerfExt="saved.lassen"
      rtol=0.15
      ;;
   ray*)
      SavePerfExt="saved.ray"
      rtol=0.15
      ;;
   *) SavePerfExt=""
      ;;
esac

if [ -n "$SavePerfExt" ]; then
   ../runcheck.sh $TNAME.perf.out $TNAME.perf.$SavePerfExt $rtol >&2
fi

#=============================================================================
# remove temporary files
#=============================================================================

rm -f ${TNAME}.testdata*
